@@ -141,10 +141,12 @@ class Grid:
         self.__initial_image = cv2.imread(image_path)
         if image_path is None:
             visu = GridVisualizer()
-            self.__initial_image = np.ones((512, 512, 3), np.uint8) * 255
-            self.__image = visu.add_upper_margin(np.zeros((512, 512, 3),
+            self.__initial_image = np.ones((1024, 1024, 3), np.uint8) * 255
+            self.__image = visu.add_upper_margin(np.zeros((1024, 1024, 3),
                                                           np.uint8),
-                                                 int(0.15 * 512))
+                                                 int(0.15 * 1024))
+        else:
+            self.__image = cv2.imread(image_path)
 
     # -------------------------- GET METHODS ------------------------- #
 
@@ -1067,8 +1069,8 @@ class Grid:
         """
         visu = GridVisualizer()
         self.__image = copy.deepcopy(self.__initial_image)
-        self.__image = visu.add_upper_margin(self.__image,
-                                             int(0.15 * self.__image.shape[0]))
+        self.__image = visu.add_upper_margin(self.get_image(),
+                                             int(0.15 * self.get_image().shape[0]))
 
     # ----------------- COMPUTE DISTANCE BETWEEN NODES -----------------#
 
